@@ -1,18 +1,22 @@
 #
 # This file is part of pyasn1 software.
 #
-# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
 # License: http://snmplabs.com/pyasn1/license.html
 #
 import sys
 
 from pyasn1 import error
-from pyasn1.type import constraint, tag, tagmap
+from pyasn1.compat import calling
+from pyasn1.type import constraint
+from pyasn1.type import tag
+from pyasn1.type import tagmap
 
-__all__ = ["Asn1Item", "Asn1Type", "SimpleAsn1Type", "ConstructedAsn1Type"]
+__all__ = ['Asn1Item', 'Asn1Type', 'SimpleAsn1Type',
+           'ConstructedAsn1Type']
 
 
-class Asn1Item:
+class Asn1Item(object):
     @classmethod
     def getTypeId(cls, increment=1):
         try:
@@ -33,7 +37,6 @@ class Asn1Type(Asn1Item):
     For as long as ASN.1 is concerned, a way to compare ASN.1 types
     is to use :meth:`isSameTypeWith` and :meth:`isSuperTypeOf` methods.
     """
-
     #: Set or return a :py:class:`~pyasn1.type.tag.TagSet` object representing
     #: ASN.1 tag(s) associated with |ASN.1| type.
     tagSet = tag.TagSet()
@@ -46,7 +49,10 @@ class Asn1Type(Asn1Item):
     typeId = None
 
     def __init__(self, **kwargs):
-        readOnly = {"tagSet": self.tagSet, "subtypeSpec": self.subtypeSpec}
+        readOnly = {
+            'tagSet': self.tagSet,
+            'subtypeSpec': self.subtypeSpec
+        }
 
         readOnly.update(kwargs)
 
@@ -55,7 +61,7 @@ class Asn1Type(Asn1Item):
         self._readOnly = readOnly
 
     def __setattr__(self, name, value):
-        if name[0] != "_" and name in self._readOnly:
+        if name[0] != '_' and name in self._readOnly:
             raise error.PyAsn1Error('read-only instance attribute "%s"' % name)
 
         self.__dict__[name] = value
@@ -69,12 +75,14 @@ class Asn1Type(Asn1Item):
 
     @property
     def effectiveTagSet(self):
-        """For |ASN.1| type is equivalent to *tagSet*"""
+        """For |ASN.1| type is equivalent to *tagSet*
+        """
         return self.tagSet  # used by untagged types
 
     @property
     def tagMap(self):
-        """Return a :class:`~pyasn1.type.tagmap.TagMap` object mapping ASN.1 tags to ASN.1 objects within callee object."""
+        """Return a :class:`~pyasn1.type.tagmap.TagMap` object mapping ASN.1 tags to ASN.1 objects within callee object.
+        """
         return tagmap.TagMap({self.tagSet: self})
 
     def isSameTypeWith(self, other, matchTags=True, matchConstraints=True):
@@ -97,11 +105,9 @@ class Asn1Type(Asn1Item):
             :obj:`True` if *other* is |ASN.1| type,
             :obj:`False` otherwise.
         """
-        return (
-            self is other
-            or (not matchTags or self.tagSet == other.tagSet)
-            and (not matchConstraints or self.subtypeSpec == other.subtypeSpec)
-        )
+        return (self is other or
+                (not matchTags or self.tagSet == other.tagSet) and
+                (not matchConstraints or self.subtypeSpec == other.subtypeSpec))
 
     def isSuperTypeOf(self, other, matchTags=True, matchConstraints=True):
         """Examine |ASN.1| type for subtype relationship with other ASN.1 type.
@@ -123,14 +129,9 @@ class Asn1Type(Asn1Item):
                 :obj:`True` if *other* is a subtype of |ASN.1| type,
                 :obj:`False` otherwise.
         """
-        return (
-            not matchTags
-            or (self.tagSet.isSuperTagSetOf(other.tagSet))
-            and (
-                not matchConstraints
-                or self.subtypeSpec.isSuperTypeOf(other.subtypeSpec)
-            )
-        )
+        return (not matchTags or
+                (self.tagSet.isSuperTagSetOf(other.tagSet)) and
+                 (not matchConstraints or self.subtypeSpec.isSuperTypeOf(other.subtypeSpec)))
 
     @staticmethod
     def isNoValue(*values):
@@ -160,12 +161,11 @@ class Asn1Type(Asn1Item):
     def hasValue(self):
         return self.isValue
 
-
 # Backward compatibility
 Asn1ItemBase = Asn1Type
 
 
-class NoValue:
+class NoValue(object):
     """Create a singleton instance of NoValue class.
 
     The *NoValue* sentinel object represents an instance of ASN.1 schema
@@ -179,57 +179,48 @@ class NoValue:
     Any operation attempted on the *noValue* object will raise the
     *PyAsn1Error* exception.
     """
-
-    skipMethods = {
-        "__slots__",
-        # attributes
-        "__getattribute__",
-        "__getattr__",
-        "__setattr__",
-        "__delattr__",
-        # class instance
-        "__class__",
-        "__init__",
-        "__del__",
-        "__new__",
-        "__repr__",
-        "__qualname__",
-        "__objclass__",
-        "im_class",
-        "__sizeof__",
-        # pickle protocol
-        "__reduce__",
-        "__reduce_ex__",
-        "__getnewargs__",
-        "__getinitargs__",
-        "__getstate__",
-        "__setstate__",
-    }
+    skipMethods = set(
+        ('__slots__',
+         # attributes
+         '__getattribute__',
+         '__getattr__',
+         '__setattr__',
+         '__delattr__',
+         # class instance
+         '__class__',
+         '__init__',
+         '__del__',
+         '__new__',
+         '__repr__',
+         '__qualname__',
+         '__objclass__',
+         'im_class',
+         '__sizeof__',
+         # pickle protocol
+         '__reduce__',
+         '__reduce_ex__',
+         '__getnewargs__',
+         '__getinitargs__',
+         '__getstate__',
+         '__setstate__')
+    )
 
     _instance = None
 
     def __new__(cls):
         if cls._instance is None:
-
             def getPlug(name):
                 def plug(self, *args, **kw):
-                    raise error.PyAsn1Error(
-                        'Attempted "%s" operation on ASN.1 schema object' % name
-                    )
-
+                    raise error.PyAsn1Error('Attempted "%s" operation on ASN.1 schema object' % name)
                 return plug
 
-            op_names = [
-                name
-                for typ in (str, int, list, dict)
-                for name in dir(typ)
-                if (
-                    name not in cls.skipMethods
-                    and name.startswith("__")
-                    and name.endswith("__")
-                    and callable(getattr(typ, name))
-                )
-            ]
+            op_names = [name
+                        for typ in (str, int, list, dict)
+                        for name in dir(typ)
+                        if (name not in cls.skipMethods and
+                            name.startswith('__') and
+                            name.endswith('__') and
+                            calling.callable(getattr(typ, name)))]
 
             for name in set(op_names):
                 setattr(cls, name, getPlug(name))
@@ -240,14 +231,12 @@ class NoValue:
 
     def __getattr__(self, attr):
         if attr in self.skipMethods:
-            raise AttributeError("Attribute %s not present" % attr)
+            raise AttributeError('Attribute %s not present' % attr)
 
-        raise error.PyAsn1Error(
-            'Attempted "%s" operation on ASN.1 schema object' % attr
-        )
+        raise error.PyAsn1Error('Attempted "%s" operation on ASN.1 schema object' % attr)
 
     def __repr__(self):
-        return "<%s object>" % self.__class__.__name__
+        return '<%s object>' % self.__class__.__name__
 
 
 noValue = NoValue()
@@ -267,7 +256,6 @@ class SimpleAsn1Type(Asn1Type):
     For as long as ASN.1 is concerned, a way to compare ASN.1 types
     is to use :meth:`isSameTypeWith` and :meth:`isSuperTypeOf` methods.
     """
-
     #: Default payload value
     defaultValue = noValue
 
@@ -282,27 +270,25 @@ class SimpleAsn1Type(Asn1Type):
 
             except error.PyAsn1Error:
                 exType, exValue, exTb = sys.exc_info()
-                raise exType(f"{exValue} at {self.__class__.__name__}")
+                raise exType('%s at %s' % (exValue, self.__class__.__name__))
 
         self._value = value
 
     def __repr__(self):
-        representation = "{} {} object".format(
-            self.__class__.__name__,
-            self.isValue and "value" or "schema",
-        )
+        representation = '%s %s object' % (
+            self.__class__.__name__, self.isValue and 'value' or 'schema')
 
         for attr, value in self.readOnly.items():
             if value:
-                representation += f", {attr} {value}"
+                representation += ', %s %s' % (attr, value)
 
         if self.isValue:
             value = self.prettyPrint()
             if len(value) > 32:
-                value = value[:16] + "..." + value[-16:]
-            representation += ", payload [%s]" % value
+                value = value[:16] + '...' + value[-16:]
+            representation += ', payload [%s]' % value
 
-        return "<%s>" % representation
+        return '<%s>' % representation
 
     def __eq__(self, other):
         return self is other and True or self._value == other
@@ -392,7 +378,7 @@ class SimpleAsn1Type(Asn1Type):
         subtype relationship between Python types. ASN.1 type is mainly identified
         by its tag(s) (:py:class:`~pyasn1.type.tag.TagSet`) and value range
         constraints (:py:class:`~pyasn1.type.constraint.ConstraintsIntersection`).
-        These ASN.1 type properties are implemented as |ASN.1| attributes.
+        These ASN.1 type properties are implemented as |ASN.1| attributes.  
 
         The `subtype()` method accepts the same set arguments as |ASN.1|
         class takes on instantiation except that all parameters
@@ -440,13 +426,13 @@ class SimpleAsn1Type(Asn1Type):
 
         initializers = self.readOnly.copy()
 
-        implicitTag = kwargs.pop("implicitTag", None)
+        implicitTag = kwargs.pop('implicitTag', None)
         if implicitTag is not None:
-            initializers["tagSet"] = self.tagSet.tagImplicitly(implicitTag)
+            initializers['tagSet'] = self.tagSet.tagImplicitly(implicitTag)
 
-        explicitTag = kwargs.pop("explicitTag", None)
+        explicitTag = kwargs.pop('explicitTag', None)
         if explicitTag is not None:
-            initializers["tagSet"] = self.tagSet.tagExplicitly(explicitTag)
+            initializers['tagSet'] = self.tagSet.tagExplicitly(explicitTag)
 
         for arg, option in kwargs.items():
             initializers[arg] += option
@@ -463,8 +449,7 @@ class SimpleAsn1Type(Asn1Type):
         return self.prettyOut(self._value)
 
     def prettyPrintType(self, scope=0):
-        return f"{self.tagSet} -> {self.__class__.__name__}"
-
+        return '%s -> %s' % (self.tagSet, self.__class__.__name__)
 
 # Backward compatibility
 AbstractSimpleAsn1Item = SimpleAsn1Type
@@ -515,9 +500,9 @@ class ConstructedAsn1Type(Asn1Type):
 
     def __init__(self, **kwargs):
         readOnly = {
-            "componentType": self.componentType,
+            'componentType': self.componentType,
             # backward compatibility, unused
-            "sizeSpec": self.sizeSpec,
+            'sizeSpec': self.sizeSpec
         }
 
         # backward compatibility: preserve legacy sizeSpec support
@@ -529,35 +514,33 @@ class ConstructedAsn1Type(Asn1Type):
 
     def _moveSizeSpec(self, **kwargs):
         # backward compatibility, unused
-        sizeSpec = kwargs.pop("sizeSpec", self.sizeSpec)
+        sizeSpec = kwargs.pop('sizeSpec', self.sizeSpec)
         if sizeSpec:
-            subtypeSpec = kwargs.pop("subtypeSpec", self.subtypeSpec)
+            subtypeSpec = kwargs.pop('subtypeSpec', self.subtypeSpec)
             if subtypeSpec:
                 subtypeSpec = sizeSpec
 
             else:
                 subtypeSpec += sizeSpec
 
-            kwargs["subtypeSpec"] = subtypeSpec
+            kwargs['subtypeSpec'] = subtypeSpec
 
         return kwargs
 
     def __repr__(self):
-        representation = "{} {} object".format(
-            self.__class__.__name__,
-            self.isValue and "value" or "schema",
+        representation = '%s %s object' % (
+            self.__class__.__name__, self.isValue and 'value' or 'schema'
         )
 
         for attr, value in self.readOnly.items():
             if value is not noValue:
-                representation += f", {attr}={value!r}"
+                representation += ', %s=%r' % (attr, value)
 
         if self.isValue and self.components:
-            representation += ", payload [%s]" % ", ".join(
-                [repr(x) for x in self.components]
-            )
+            representation += ', payload [%s]' % ', '.join(
+                [repr(x) for x in self.components])
 
-        return "<%s>" % representation
+        return '<%s>' % representation
 
     def __eq__(self, other):
         return self is other or self.components == other
@@ -582,7 +565,7 @@ class ConstructedAsn1Type(Asn1Type):
 
     @property
     def components(self):
-        raise error.PyAsn1Error("Method not implemented")
+        raise error.PyAsn1Error('Method not implemented')
 
     def _cloneComponentValues(self, myClone, cloneValueFlag):
         pass
@@ -610,7 +593,7 @@ class ConstructedAsn1Type(Asn1Type):
         Due to the mutable nature of the |ASN.1| object, even if no arguments
         are supplied, a new |ASN.1| object will be created and returned.
         """
-        cloneValueFlag = kwargs.pop("cloneValueFlag", False)
+        cloneValueFlag = kwargs.pop('cloneValueFlag', False)
 
         initializers = self.readOnly.copy()
         initializers.update(kwargs)
@@ -666,15 +649,15 @@ class ConstructedAsn1Type(Asn1Type):
 
         initializers = self.readOnly.copy()
 
-        cloneValueFlag = kwargs.pop("cloneValueFlag", False)
+        cloneValueFlag = kwargs.pop('cloneValueFlag', False)
 
-        implicitTag = kwargs.pop("implicitTag", None)
+        implicitTag = kwargs.pop('implicitTag', None)
         if implicitTag is not None:
-            initializers["tagSet"] = self.tagSet.tagImplicitly(implicitTag)
+            initializers['tagSet'] = self.tagSet.tagImplicitly(implicitTag)
 
-        explicitTag = kwargs.pop("explicitTag", None)
+        explicitTag = kwargs.pop('explicitTag', None)
         if explicitTag is not None:
-            initializers["tagSet"] = self.tagSet.tagExplicitly(explicitTag)
+            initializers['tagSet'] = self.tagSet.tagExplicitly(explicitTag)
 
         for arg, option in kwargs.items():
             initializers[arg] += option
@@ -687,10 +670,10 @@ class ConstructedAsn1Type(Asn1Type):
         return clone
 
     def getComponentByPosition(self, idx):
-        raise error.PyAsn1Error("Method not implemented")
+        raise error.PyAsn1Error('Method not implemented')
 
     def setComponentByPosition(self, idx, value, verifyConstraints=True):
-        raise error.PyAsn1Error("Method not implemented")
+        raise error.PyAsn1Error('Method not implemented')
 
     def setComponents(self, *args, **kwargs):
         for idx, value in enumerate(args):
@@ -711,7 +694,6 @@ class ConstructedAsn1Type(Asn1Type):
     def verifySizeSpec(self):
         self.subtypeSpec(self)
 
+
         # Backward compatibility
-
-
 AbstractConstructedAsn1Item = ConstructedAsn1Type
