@@ -1,7 +1,7 @@
 #
 # This file is part of pyasn1 software.
 #
-# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
 # License: http://snmplabs.com/pyasn1/license.html
 #
 # Original concept and code by Mike C. Fletcher.
@@ -10,20 +10,15 @@ import sys
 
 from pyasn1.type import error
 
-__all__ = [
-    "SingleValueConstraint",
-    "ContainedSubtypeConstraint",
-    "ValueRangeConstraint",
-    "ValueSizeConstraint",
-    "PermittedAlphabetConstraint",
-    "InnerTypeConstraint",
-    "ConstraintsExclusion",
-    "ConstraintsIntersection",
-    "ConstraintsUnion",
-]
+__all__ = ['SingleValueConstraint', 'ContainedSubtypeConstraint',
+           'ValueRangeConstraint', 'ValueSizeConstraint',
+           'PermittedAlphabetConstraint', 'InnerTypeConstraint',
+           'ConstraintsExclusion', 'ConstraintsIntersection',
+           'ConstraintsUnion']
 
 
-class AbstractConstraint:
+class AbstractConstraint(object):
+
     def __init__(self, *values):
         self._valueMap = set()
         self._setValues(values)
@@ -37,15 +32,18 @@ class AbstractConstraint:
             self._testValue(value, idx)
 
         except error.ValueConstraintError:
-            raise error.ValueConstraintError(f"{self} failed at: {sys.exc_info()[1]!r}")
+            raise error.ValueConstraintError(
+                '%s failed at: %r' % (self, sys.exc_info()[1])
+            )
 
     def __repr__(self):
-        representation = "%s object" % (self.__class__.__name__)
+        representation = '%s object' % (self.__class__.__name__)
 
         if self._values:
-            representation += ", consts %s" % ", ".join([repr(x) for x in self._values])
+            representation += ', consts %s' % ', '.join(
+                [repr(x) for x in self._values])
 
-        return "<%s>" % representation
+        return '<%s>' % representation
 
     def __eq__(self, other):
         return self is other and True or self._values == other
@@ -83,20 +81,16 @@ class AbstractConstraint:
 
     def isSuperTypeOf(self, otherConstraint):
         # TODO: fix possible comparison of set vs scalars here
-        return (
-            otherConstraint is self
-            or not self._values
-            or otherConstraint == self
-            or self in otherConstraint.getValueMap()
-        )
+        return (otherConstraint is self or
+                not self._values or
+                otherConstraint == self or
+                self in otherConstraint.getValueMap())
 
     def isSubTypeOf(self, otherConstraint):
-        return (
-            otherConstraint is self
-            or not self
-            or otherConstraint == self
-            or otherConstraint in self._valueMap
-        )
+        return (otherConstraint is self or
+                not self or
+                otherConstraint == self or
+                otherConstraint in self._valueMap)
 
 
 class SingleValueConstraint(AbstractConstraint):
@@ -136,7 +130,6 @@ class SingleValueConstraint(AbstractConstraint):
         # this will raise ValueConstraintError
         divisor_of_six = DivisorOfSix(7)
     """
-
     def _setValues(self, values):
         self._values = values
         self._set = set(values)
@@ -199,7 +192,6 @@ class ContainedSubtypeConstraint(AbstractConstraint):
         # this will raise ValueConstraintError
         divisor_of_eighteen = DivisorOfEighteen(10)
     """
-
     def _testValue(self, value, idx):
         for constraint in self._values:
             if isinstance(constraint, AbstractConstraint):
@@ -244,19 +236,22 @@ class ValueRangeConstraint(AbstractConstraint):
         # this will raise ValueConstraintError
         teen_year = TeenAgeYears(20)
     """
-
     def _testValue(self, value, idx):
         if value < self.start or value > self.stop:
             raise error.ValueConstraintError(value)
 
     def _setValues(self, values):
         if len(values) != 2:
-            raise error.PyAsn1Error(f"{self.__class__.__name__}: bad constraint values")
+            raise error.PyAsn1Error(
+                '%s: bad constraint values' % (self.__class__.__name__,)
+            )
         self.start, self.stop = values
         if self.start > self.stop:
             raise error.PyAsn1Error(
-                "%s: screwed constraint values (start > stop): %s > %s"
-                % (self.__class__.__name__, self.start, self.stop)
+                '%s: screwed constraint values (start > stop): %s > %s' % (
+                    self.__class__.__name__,
+                    self.start, self.stop
+                )
             )
         AbstractConstraint._setValues(self, values)
 
@@ -315,7 +310,6 @@ class ValueSizeConstraint(ValueRangeConstraint):
     than schema instantiation phase (as it is with immutable
     types).
     """
-
     def _testValue(self, value, idx):
         valueSize = len(value)
         if valueSize < self.start or valueSize > self.stop:
@@ -397,7 +391,6 @@ class PermittedAlphabetConstraint(SingleValueConstraint):
     Therefore it's more practical to model `EXCEPT` clause at
     `PermittedAlphabetConstraint` level instead.
     """
-
     def _setValues(self, values):
         self._values = values
         self._set = set(values)
@@ -428,16 +421,16 @@ class ComponentPresentConstraint(AbstractConstraint):
         # this will raise ValueConstraintError
         present(None)
     """
-
     def _setValues(self, values):
-        self._values = ("<must be present>",)
+        self._values = ('<must be present>',)
 
         if values:
-            raise error.PyAsn1Error("No arguments expected")
+            raise error.PyAsn1Error('No arguments expected')
 
     def _testValue(self, value, idx):
         if value is None:
-            raise error.ValueConstraintError("Component is not present:")
+            raise error.ValueConstraintError(
+                'Component is not present:')
 
 
 class ComponentAbsentConstraint(AbstractConstraint):
@@ -461,16 +454,16 @@ class ComponentAbsentConstraint(AbstractConstraint):
         # this will raise ValueConstraintError
         absent('whatever')
     """
-
     def _setValues(self, values):
-        self._values = ("<must be absent>",)
+        self._values = ('<must be absent>',)
 
         if values:
-            raise error.PyAsn1Error("No arguments expected")
+            raise error.PyAsn1Error('No arguments expected')
 
     def _testValue(self, value, idx):
         if value is not None:
-            raise error.ValueConstraintError("Component is not absent: %r" % value)
+            raise error.ValueConstraintError(
+                'Component is not absent: %r' % value)
 
 
 class WithComponentsConstraint(AbstractConstraint):
@@ -544,7 +537,6 @@ class WithComponentsConstraint(AbstractConstraint):
         descr['id'] = 1
         descr['name'] = 'John'
     """
-
     def _testValue(self, value, idx):
         for field, constraint in self._values:
             constraint(value.get(field))
@@ -564,7 +556,7 @@ class InnerTypeConstraint(AbstractConstraint):
             if idx not in self.__multipleTypeConstraint:
                 raise error.ValueConstraintError(value)
             constraint, status = self.__multipleTypeConstraint[idx]
-            if status == "ABSENT":  # XXX presence is not checked!
+            if status == 'ABSENT':  # XXX presence is not checked!
                 raise error.ValueConstraintError(value)
             constraint(value)
 
@@ -581,7 +573,6 @@ class InnerTypeConstraint(AbstractConstraint):
 
 # Logic operations on constraints
 
-
 class ConstraintsExclusion(AbstractConstraint):
     """Create a ConstraintsExclusion logic operator object.
 
@@ -617,7 +608,6 @@ class ConstraintsExclusion(AbstractConstraint):
     constraint objects into one. See `PermittedAlphabetConstraint` for more
     information.
     """
-
     def _testValue(self, value, idx):
         for constraint in self._values:
             try:
@@ -633,6 +623,7 @@ class ConstraintsExclusion(AbstractConstraint):
 
 
 class AbstractConstraintSet(AbstractConstraint):
+
     def __getitem__(self, idx):
         return self._values[idx]
 
@@ -697,7 +688,6 @@ class ConstraintsIntersection(AbstractConstraintSet):
         # this will raise ValueConstraintError
         capital_and_small = CapitalAndSmall('hello')
     """
-
     def _testValue(self, value, idx):
         for constraint in self._values:
             constraint(value, idx)
@@ -742,7 +732,6 @@ class ConstraintsUnion(AbstractConstraintSet):
         # this will raise ValueConstraintError
         capital_or_small = CapitalOrSmall('hello!')
     """
-
     def _testValue(self, value, idx):
         for constraint in self._values:
             try:
@@ -752,8 +741,9 @@ class ConstraintsUnion(AbstractConstraintSet):
             else:
                 return
 
-        raise error.ValueConstraintError(f'all of {self._values} failed for "{value}"')
-
+        raise error.ValueConstraintError(
+            'all of %s failed for "%s"' % (self._values, value)
+        )
 
 # TODO:
 # refactor InnerTypeConstraint
