@@ -1,17 +1,24 @@
 #
 # This file is part of pyasn1 software.
 #
-# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
 # License: http://snmplabs.com/pyasn1/license.html
 #
 import sys
-import unittest
+
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
+
+from tests.base import BaseTestCase
 
 from pyasn1.compat import integer
-from tests.base import BaseTestCase
 
 
 class IntegerTestCase(BaseTestCase):
+
+
     def test_from_bytes_zero(self):
         assert 0 == integer.from_bytes(bytes([0]), signed=False)
 
@@ -25,7 +32,8 @@ class IntegerTestCase(BaseTestCase):
         assert 0 == integer.from_bytes(bytes([]))
 
 
+
 suite = unittest.TestLoader().loadTestsFromModule(sys.modules[__name__])
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     unittest.TextTestRunner(verbosity=2).run(suite)
